@@ -7,7 +7,13 @@ var classOfxBalanceContainer =
     [ "add_attribute", "classOfxBalanceContainer.html#a85951ca6d29aeace59a9ca86453e8abb", null ],
     [ "add_attribute", "classOfxBalanceContainer.html#a85951ca6d29aeace59a9ca86453e8abb", null ],
     [ "amount", "classOfxBalanceContainer.html#afff1080e7dc3a6f6e09f1c0d9c1dc68f", null ],
-    [ "amount_valid", "classOfxBalanceContainer.html#a8ec139f87dfed172199cae86c4441c34", null ],
+    [ "amount_valid", "classOfxBalanceContainer.html#ad2279647ff30bb729e0cea1315340dd3", null ],
+    [ "buying_power", "classOfxBalanceContainer.html#aeebf9284b9566bfe03984df2f11ffcb2", null ],
+    [ "buying_power_valid", "classOfxBalanceContainer.html#a8b4bc4634dd08e09cb984081efea4130", null ],
     [ "date", "classOfxBalanceContainer.html#a63069560ec9ee3524688452b00f0a39d", null ],
-    [ "date_valid", "classOfxBalanceContainer.html#a63784a0db798c12aede0e3ff54888916", null ]
+    [ "date_valid", "classOfxBalanceContainer.html#a6db99feb3a273a0de86d96cb2e619eec", null ],
+    [ "margin_balance", "classOfxBalanceContainer.html#acc16b766f7914991bf8d02442f5fe9e1", null ],
+    [ "margin_balance_valid", "classOfxBalanceContainer.html#a5862922c29e3fc26d2d5adc396a61770", null ],
+    [ "short_balance", "classOfxBalanceContainer.html#a8fda7959ac18897ffba03443de39c20a", null ],
+    [ "short_balance_valid", "classOfxBalanceContainer.html#ad2413af7247d7681ef7a244c2fefeb85", null ]
 ];
\ No newline at end of file
